/*
 * File: especies.h
 * ---------------
 * Esta interface define a abstraçéao espcies.
 */
#ifndef _especies_h
#define _especies_h

/*
 * Type: especiesTAD
 * ----------------
 * Este é o tipo abstrato de dados para as espécies.
 */
typedef struct especiesCDT *especiesTAD;
/*
 * Tipo: opcodeT
 * -------------
 * O tipo opcodeT é uma enumeração dos comandos válidos
.
 */
typedef enum {
    frente, esquerda, direita, infecta,
    SeVazio, SeBorda, SeIgual, SeInimigo, SeAleatorio,
    VaPara
} opcodeT;


/*
 * Tipo: instrucaoT
 * ------------------
 * O tipo instrucaoT é usado para representar uma instrução
 * e consiste de um par de um código de operação e um inteiro.
 */
typedef struct {
    opcodeT op;
    int endereco;
} instrucaoT;

/*
 * Função: LerEspecies
 * Uso: especies = LerEspecies(nomearquivo);
 * ---------------------------------------
 * Esta função lê para uma nova espécie a partir de um arquivo específico.
 * Para encontrar o arquivo, a função procura em um subdiretório denominado
 * "Criaturas". Se não existe um arquivo com o nome indicado
 * naquele subdiretório, a função retorna NULL.
 */
especiesTAD LerEspecies(string nomearquivo);
/*
 * Função: NomeEspecies
 * Uso: nome = NomeEspecies(especies);
 * -----------------------------------
 * Esta função retorna o nome de uma espécie existente.
 */
char * NomeEspecies(especiesTAD especies);
/*
 * Função: TamanhoPrograma
 * Uso: nPassos = TamanhoPrograma(especies);
 * -------------------------------------
 * Esta função retorna o número de instruções no programa
 * para aquela espécie.
 */
int TamanhoPrograma(especiesTAD especies);
/*
 * Função: PassoPrograma
 * Uso: comando = PassoPrograma(especies, k);
 * -------------------------------------------
 * Esta função retorna a  k-ésima instrução no programa para
 * aquela espécie, sendo os passos numerados no início a partir de 1.
 * Atente que selecionar uma instrução fora da faixa do programa
 * gera um erro.
 */
instrucaoT PassoPrograma(especiesTAD especies, int k);

#endif
